
#ifndef OBJECTSTORAGE_H
#define OBJECTSTORAGE_H
#define MAX_POLY 50

enum EObjectTypes
{
	ePolyObj=1,
	eLineObj=2
};

class AngLenPair
{
public:
	double m_ang;
	double m_len;
	AngLenPair(double a, double l) {m_ang=a; m_len=l;}
	AngLenPair() {m_ang=0.;m_len=0.;}
};

class CObjectStorage : public CObject
{
protected:
	EObjectTypes eObjType;
	int bkred,bkgreen,bkblue;
	int fgred,fggreen,fgblue;
	CList<AngLenPair,AngLenPair&> coordinates;
public:
	// construction and destruction of object.
	DECLARE_DYNAMIC(CObjectStorage)
					CObjectStorage() {bkred=bkgreen=bkblue=255;fgred=fgblue=fggreen=0;}
	virtual			~CObjectStorage(void) {;}

	// type checking
	EObjectTypes	GetObjectType(void) {return eObjType;}
	void			AddPoint(double ang,double len) {coordinates.AddTail(AngLenPair(ang,len));}

	// overides (pure abstract)
	virtual void	OutputCoordinates(CFile *file); // throws CFileException
	virtual void	Draw(CDC*,double,double,CPoint)=0;
	void			SetFgRGB(int r,int g,int b) {fgred=r;fggreen=g;fgblue=b;}
	void			SetBkRGB(int r,int g,int b) {bkred=r;bkgreen=g;bkblue=b;}
};


class CLineStorage : public CObjectStorage
{

public:
	DECLARE_DYNAMIC(CLineStorage)
	CLineStorage() : CObjectStorage() {eObjType = eLineObj;}
	virtual void	Draw(CDC *pDC,double scale,double rot_2d,CPoint centre);
};

class CPolyStorage : public CObjectStorage
{

public:
	DECLARE_DYNAMIC(CPolyStorage)
	CPolyStorage() : CObjectStorage() {eObjType = ePolyObj;}
	virtual void	Draw(CDC *pDC,double scale,double rot_2d,CPoint centre);
};


#endif
